==> playfunads-2.0-sources.jar: playfun/ads/android/sdk/component/util/UserInfor.java <==
package playfun.ads.android.sdk.component.util;

import android.os.Build;

public class UserInfor {

    public static UserInfor INSTACE;
    private String device_name = "", device_os = "",device_resolution = "",userId = "",
            advertisingId = "",package_name = "",bundleId = "",version_name = "",version_code = "",
            orientation = "" , isVip = "";
    public synchronized static UserInfor getInstance() {
        if (INSTACE == null) {
            INSTACE = new UserInfor();
        }
        return INSTACE;
    }

    public String getIsVip() {
        return isVip;
    }

    public void setIsVip(String isVip) {
        this.isVip = isVip;
    }

    public String getDevice_name() {
        return Build.PRODUCT;
    }

    public void setDevice_name(String device_name) {
        this.device_name = device_name;
    }

    public String getDevice_os() {
        return "Android OS" + Build.VERSION.RELEASE;
    }

    public void setDevice_os(String device_os) {
        this.device_os = device_os;
    }

    public String getDevice_resolution() {
        return device_resolution;
    }

    public void setDevice_resolution(String device_resolution) {
        this.device_resolution = device_resolution;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getAdvertisingId() {
        return advertisingId;
    }

    public void setAdvertisingId(String advertisingId) {
        this.advertisingId = advertisingId;
    }

    public String getPackage_name() {
        return package_name;
    }

    public void setPackage_name(String package_name) {
        this.package_name = package_name;
    }

    public String getBundleId() {
        return bundleId;
    }

    public void setBundleId(String bundleId) {
        this.bundleId = bundleId;
    }

    public String getVersion_name() {
        return version_name;
    }

    public void setVersion_name(String version_name) {
        this.version_name = version_name;
    }

    public String getVersion_code() {
        return version_code;
    }

    public void setVersion_code(String version_code) {
        this.version_code = version_code;
    }

    public String getOrientation() {
        return orientation;
    }

    public void setOrientation(String orientation) {
        this.orientation = orientation;
    }
}

==> playfunads-3.0.3-sources.jar: playfun/ads/android/sdk/component/util/UserInfor.java <==
package playfun.ads.android.sdk.component.util;

import android.os.Build;

public class UserInfor {

    public static UserInfor INSTACE;
    private String device_name = "", device_os = "",device_resolution = "",userId = "",
            advertisingId = "",package_name = "",bundleId = "",version_name = "",version_code = "",
            orientation = "" , isVip = "" , inventoryId = "" , adsKey = "";
    public synchronized static UserInfor getInstance() {
        if (INSTACE == null) {
            INSTACE = new UserInfor();
        }
        return INSTACE;
    }

    public String getIsVip() {
        return isVip;
    }

    public void setIsVip(String isVip) {
        this.isVip = isVip;
    }

    public String getDevice_name() {
        return Build.PRODUCT;
    }

    public void setDevice_name(String device_name) {
        this.device_name = device_name;
    }

    public String getDevice_os() {
        return "Android OS" + Build.VERSION.RELEASE;
    }

    public void setDevice_os(String device_os) {
        this.device_os = device_os;
    }

    public String getDevice_resolution() {
        return device_resolution;
    }

    public void setDevice_resolution(String device_resolution) {
        this.device_resolution = device_resolution;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getAdvertisingId() {
        return advertisingId;
    }

    public String getInventoryId() {
        return inventoryId;
    }

    public void setInventoryId(String inventoryId) {
        this.inventoryId = inventoryId;
    }

    public String getAdsKey() {
        return adsKey;
    }

    public void setAdsKey(String adsKey) {
        this.adsKey = adsKey;
    }

    public void setAdvertisingId(String advertisingId) {
        this.advertisingId = advertisingId;
    }

    public String getPackage_name() {
        return package_name;
    }

    public void setPackage_name(String package_name) {
        this.package_name = package_name;
    }

    public String getBundleId() {
        return bundleId;
    }

    public void setBundleId(String bundleId) {
        this.bundleId = bundleId;
    }

    public String getVersion_name() {
        return version_name;
    }

    public void setVersion_name(String version_name) {
        this.version_name = version_name;
    }

    public String getVersion_code() {
        return version_code;
    }

    public void setVersion_code(String version_code) {
        this.version_code = version_code;
    }

    public String getOrientation() {
        return orientation;
    }

    public void setOrientation(String orientation) {
        this.orientation = orientation;
    }
}
